#!/bin/bash
# NdisWrapper configuration script
# (C) Martin Oehler 2004
# 2005 Alessandro Gervaso <alessandro@truelite.it>

PATH="/bin:/sbin:/usr/bin:/usr/sbin:/usr/X11R6/bin:/usr/local/bin"
export PATH

# Get root
[ "`id -u`" != "0" ] && exec gksu "$0" "$@"

TMP="/tmp/ndiswrapper.$$"

DIALOG="zenity"

# this error is displayed when something is wrong eith the
# inf file
inf_error() {
  $DIALOG --error --error-text "Il file selezionato non e' un *.inf oppure il formato non e' valido."
}


# at first we show the usual disclaimer that the usage of this
# script could simply destroy everything

$DIALOG --info --title="Fuss-Ndiswrapper" --text="This is the configuration tool for the ndiswrapper utilities.
Be aware that loading a windows driver file for your
wlan card using this tool could freeze your system. 

You need matching driver.inf and driver.sys files residing on
a mounted data medium. After the windows drivers have been
successfully loaded via the ndiswrapper, you have to configure
your wlan settings via iwconfig. Future releases of this script
will include this."

DRIVER_PATH=$($DIALOG --file-selection --title="Fuss-Ndiswrapper");

test -x "/usr/sbin/ndiswrapper" || { echo "NdisWrapper not found, exiting." >&2; exit 1; }
test -x "/sbin/modprobe" || { echo "modprobe not found, exiting." >&2; exit 1; }
test -e $DRIVER_PATH || { echo "$DRIVER_PATH does not exist, exiting." >&2; exit 1; }
case "$DRIVER_PATH" in 
  *\.inf*) NUM=`grep -c "sys" "$DRIVER_PATH"`
           if [ "$NUM" -lt 1 ]; then 
	     inf_error; exit 1;
	   fi;;
  *) inf_error; exit 1; 
esac

# how much lines are in /proc/net/wireless 
LINES1=`cat /proc/net/wireless | wc -l`

ndiswrapper -i $DRIVER_PATH
modprobe ndiswrapper
ndiswrapper -m

# have we got a new device?
LINES2=`cat /proc/net/wireless | wc -l`

if [ "$LINES2" -gt "$LINES1" ]; then
  $DIALOG --info --title="Fuss-Ndiswrapper" --text="The ndiswrapper module has been loaded. You may configure your wlan card with iwconfig now."
else
  $DIALOG --info --title="Fuss-Ndiswrapper" --text="The ndiswrapper module has been loaded but there is no new device. Perhaps NdisWrapper is not working with your driver file.";
fi
